/* Mapeamento dos códigos vindos do Bluetooth
 * 
 * *********** Status desejado de cada funcionalidade do HERO ***********************
 * Funcionalidade   ->  Sirene  LED   Obstáculo    Segue Linha    Testar
 * Ligar            ->  1       3     5            7              9
 * Desligar         ->  2       4     15           15             15
 * 
 * *********** Dirigibilidade do HERO **********************************************
 * Sentido          ->  Frente  Ré    Direita       Esquerda      Parar
 * Código           ->  11      12    13            14            15
 */

//Importação da biblioteca de comandos simplificados
#include <darwin.h>

//Armazenará os comandos vindos do Bluetooth
int comando;

//Armazenará os valores dos sensores de infravermelho
float CorNaPortaA1, CorNaPortaA2, MediaDasCores;


void setup() {
  //Configurações iniciais para receber os dados do Bluetooth
  AtivarBluetooth();
 
  //Definição dos dispositivos nas portas digitais
  SireneNaPorta(D13);
  LedNaPorta(D12);

  //Definiação dos motores nas portas digitais
  AtivarMotores();
  
}

void loop() {
  
  //Recebe o dados vindos do Bluetooth
  comando = ReceberNumeroPeloBluetooth();

  //Ligar a sirene
  if (comando==1)
    LigarSirene(D13);
    
  //Desligar a sirene
  if (comando==2)
    DesligarSirene(D13);

  //Ligar o led
  if (comando==3)
    LigarLed(D12);
    
  //Desligar o led
  if (comando==4)
    DesligarLed(D12);
 
  //Carro vai para frente
  if (comando==11)
  {
    MotorM1(Re);
    MotorM2(Re);
  }
    
  //Carro vai para trás
  if (comando==12)
  {
    MotorM1(Frente);
    MotorM2(Frente);
  }

  //Carro vai para direita
  if (comando==13)
  {
    MotorM1(Frente);
    MotorM2(Re);
  }

  //Carro vai para esquerda
  if (comando==14)
  {
    MotorM1(Re);
    MotorM2(Frente);
  }

  //Configura o carro para desviar de obstáculos
  if (comando==5)
  {
    while (comando!=15)
    {

      if(LerDistancia()>30)
      {
        MotorM1(Re);
        MotorM2(Frente);
      }
      else
      {
        MotorM1(Frente);
        MotorM2(Frente);
        EsperarSegundos(1);
      }
  
      //Recebe o dados vindos do Bluetooth
      comando = ReceberNumeroPeloBluetooth();
    }

  }


  //Configura o carro para seguir uma faixa escura fixada no chão
  if (comando==7)
  {
 
    while (comando!=15)
    {
     
      CorNaPortaA1 = LeituraDaPorta(A1);  
      CorNaPortaA2 = LeituraDaPorta(A2);
      MediaDasCores = (CorNaPortaA1 + CorNaPortaA2)/2;
       
      if(CorNaPortaA1 <= MediaDasCores) 
          MotorM1(Frente);
      else
          MotorM1(Parar);

      if(CorNaPortaA2 <= MediaDasCores)
          MotorM2(Frente);
      else
          MotorM2(Parar);
      
      //Recebe o dados vindos do Bluetooth
      comando =  ReceberNumeroPeloBluetooth();
    }

  }

  //Configura o carro para testar os motores, o LED e a sirene
  if (comando==9)
  {
    
    while (comando!=15)
    {
      //Ligar a sirene
      LigarSirene(D13);
      //Ligar o led
      LigarLed(D12);
        
      //Carro vai para frente
      MotorM1(Re);
      MotorM2(Frente);
      EsperarSegundos(2);
  
      //Desligar a sirene
      DesligarSirene(D13);
      //Desligar o led
      DesligarLed(D12);
      
      //Carro vai para esquerda
      MotorM1(Frente);
      MotorM2(Re);
      EsperarSegundos(0.5);
      
      //Recebe o dados vindos do Bluetooth
      comando = ReceberNumeroPeloBluetooth();
    }

  }

  //Parar o carro
  if (comando==15)
  {
    MotorM1(Parar);
    MotorM2(Parar);
  }

    
}
